{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/data_type"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#add_bam_readcount_to_vcf.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#add_bam_readcount_to_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/add_annotations_to_table_helper.py"
            ],
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "",
                        "itemSeparator": ",",
                        "separate": false,
                        "position": 3
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#coding_variant_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#coding_variant_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#coding_variant_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "varscan,docm",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/docm_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#germline_combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#germline_combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#germline_combine_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "gnomADe_AF filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            \"gnomADe_AF\", \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", \"gnomADe_AF\"\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#gnomADe_AF_filter.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#gnomADe_AF_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#gnomADe_AF_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#gnomADe_AF_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "Tumor-Only Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "id": "#tumor_only_detect_variants.cwl/coding_only"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai",
                        ".crai"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/custom_gnomad_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/docm_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "id": "#tumor_only_detect_variants.cwl/hgvs_annotation"
                },
                {
                    "type": "File",
                    "id": "#tumor_only_detect_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.001,
                    "id": "#tumor_only_detect_variants.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "id": "#tumor_only_detect_variants.cwl/reference"
                },
                {
                    "type": "string",
                    "id": "#tumor_only_detect_variants.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/synonyms_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "GT",
                        "AD",
                        "AF",
                        "DP"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#tumor_only_detect_variants.cwl/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#tumor_only_detect_variants.cwl/varscan_min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#tumor_only_detect_variants.cwl/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#tumor_only_detect_variants.cwl/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#tumor_only_detect_variants.cwl/varscan_strand_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/vep_cache_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature_type",
                        "Feature",
                        "HGVSc",
                        "HGVSp",
                        "cDNA_position",
                        "CDS_position",
                        "Protein_position",
                        "Amino_acids",
                        "Codons",
                        "HGNC_ID",
                        "Existing_variation",
                        "gnomADe_AF",
                        "CLIN_SIG",
                        "SOMATIC",
                        "PHENO"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/docm/unfiltered_vcf",
                    "id": "#tumor_only_detect_variants.cwl/docm_gatk_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#tumor_only_detect_variants.cwl/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/index_filtered/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/bam_readcount/bam_readcount_tsv",
                    "id": "#tumor_only_detect_variants.cwl/tumor_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/varscan_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#tumor_only_detect_variants.cwl/annotate_variants/vep_summary",
                    "id": "#tumor_only_detect_variants.cwl/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#add_bam_readcount_to_vcf.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/bam_readcount/bam_readcount_tsv",
                            "id": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "default": "DNA",
                            "id": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/sample_name",
                            "id": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/annotate_variants/annotated_vcf",
                            "id": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/variants_to_table/variants_tsv",
                            "id": "#tumor_only_detect_variants.cwl/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/index_filtered/indexed_vcf",
                            "id": "#tumor_only_detect_variants.cwl/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/vep_to_table_fields",
                            "id": "#tumor_only_detect_variants.cwl/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/add_vep_fields_to_table"
                },
                {
                    "run": "#gnomADe_AF_filter.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/maximum_population_allele_frequency",
                            "id": "#tumor_only_detect_variants.cwl/af_filter/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/hard_filter/filtered_vcf",
                            "id": "#tumor_only_detect_variants.cwl/af_filter/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/af_filter/filtered_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/af_filter"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/vep_cache_dir",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/coding_only",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/coding_only"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/custom_gnomad_vcf",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/hgvs_annotation",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/hgvs"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/reference"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/synonyms_file",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/combine_variants/combined_vcf",
                            "id": "#tumor_only_detect_variants.cwl/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/annotate_variants/annotated_vcf",
                        "#tumor_only_detect_variants.cwl/annotate_variants/vep_summary"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/annotate_variants"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/cram_to_bam/bam",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/bam"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/min_base_quality",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/min_mapping_quality",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/sample_name",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/sample"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/combine_variants/combined_vcf",
                            "id": "#tumor_only_detect_variants.cwl/bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/bam_readcount/bam_readcount_tsv"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/bam_readcount"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/coding_variant_filter/filtered_vcf",
                            "id": "#tumor_only_detect_variants.cwl/bgzip_filtered/file"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/bgzip_filtered/bgzipped_file"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/bgzip_filtered"
                },
                {
                    "run": "#coding_variant_filter.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/af_filter/filtered_vcf",
                            "id": "#tumor_only_detect_variants.cwl/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/coding_variant_filter"
                },
                {
                    "run": "#germline_combine_variants.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/docm/filtered_vcf",
                            "id": "#tumor_only_detect_variants.cwl/combine_variants/docm_vcf"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/combine_variants/reference"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan/filtered_vcf",
                            "id": "#tumor_only_detect_variants.cwl/combine_variants/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/combine_variants/combined_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/combine_variants"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/cram",
                            "id": "#tumor_only_detect_variants.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/cram_to_bam/bam"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/cram_to_bam"
                },
                {
                    "run": "#germline_workflow.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/cram",
                            "id": "#tumor_only_detect_variants.cwl/docm/cram"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/docm_vcf",
                            "id": "#tumor_only_detect_variants.cwl/docm/docm_vcf"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/interval_list",
                            "id": "#tumor_only_detect_variants.cwl/docm/interval_list"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/docm/reference"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/docm/unfiltered_vcf",
                        "#tumor_only_detect_variants.cwl/docm/filtered_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/docm"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#tumor_only_detect_variants.cwl/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/interval_list",
                            "id": "#tumor_only_detect_variants.cwl/hard_filter/interval_list"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/hard_filter/reference"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/index/indexed_vcf",
                            "id": "#tumor_only_detect_variants.cwl/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/hard_filter/filtered_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/hard_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#tumor_only_detect_variants.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/index/indexed_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/index"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/bgzip_filtered/bgzipped_file",
                            "id": "#tumor_only_detect_variants.cwl/index_filtered/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/index_filtered/indexed_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/index_filtered"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/variants_to_table_fields",
                            "id": "#tumor_only_detect_variants.cwl/variants_to_table/fields"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/variants_to_table_genotype_fields",
                            "id": "#tumor_only_detect_variants.cwl/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/variants_to_table/reference"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/index_filtered/indexed_vcf",
                            "id": "#tumor_only_detect_variants.cwl/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/variants_to_table/variants_tsv"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/variants_to_table"
                },
                {
                    "run": "#germline_workflow.cwl_2",
                    "in": [
                        {
                            "source": "#tumor_only_detect_variants.cwl/cram",
                            "id": "#tumor_only_detect_variants.cwl/varscan/cram"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/interval_list",
                            "id": "#tumor_only_detect_variants.cwl/varscan/interval_list"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan_min_coverage",
                            "id": "#tumor_only_detect_variants.cwl/varscan/min_coverage"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan_min_reads",
                            "id": "#tumor_only_detect_variants.cwl/varscan/min_reads"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan_min_var_freq",
                            "id": "#tumor_only_detect_variants.cwl/varscan/min_var_freq"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan_p_value",
                            "id": "#tumor_only_detect_variants.cwl/varscan/p_value"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/reference",
                            "id": "#tumor_only_detect_variants.cwl/varscan/reference"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/sample_name",
                            "id": "#tumor_only_detect_variants.cwl/varscan/sample_name"
                        },
                        {
                            "source": "#tumor_only_detect_variants.cwl/varscan_strand_filter",
                            "id": "#tumor_only_detect_variants.cwl/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#tumor_only_detect_variants.cwl/varscan/unfiltered_vcf",
                        "#tumor_only_detect_variants.cwl/varscan/filtered_vcf"
                    ],
                    "id": "#tumor_only_detect_variants.cwl/varscan"
                }
            ],
            "id": "#tumor_only_detect_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--plugin",
                "Downstream",
                "--plugin",
                "Wildtype",
                "--symbol",
                "--term",
                "SO",
                "--flag_pick",
                "--transcript_version",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.cache_dir) {\n        return [\"--offline\", \"--cache\", \"--dir\", inputs.cache_dir ]\n    }\n    else {\n        return \"--database\"\n    }\n}\n",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        if (inputs.cache_dir) {\n            return ['--max_af', '--af_gnomad', '--af_1kg']\n        }\n        else {\n            return []\n        }\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.hgvs) {\n        if (inputs.cache_dir) {\n            return [\"--hgvs\", \"--fasta\", inputs.reference]\n        }\n        else {\n            return [\"--hgvs\"]\n        }\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 5
                    },
                    "id": "#vep.cwl/hgvs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "-gt_mode",
                "GENOTYPE_GIVEN_ALLELES",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/docm_out.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_gatk_haplotypecaller.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--alleles",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_gatk_haplotypecaller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/interval_list"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_out.vcf"
                    },
                    "id": "#germline_gatk_haplotypecaller.cwl/docm_out"
                }
            ],
            "id": "#germline_gatk_haplotypecaller.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect DoCM variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_workflow.cwl/cram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#germline_workflow.cwl/interval_list"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl/gatk_haplotypecaller/docm_out",
                    "id": "#germline_workflow.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/docm_filter/docm_filter_out",
                            "id": "#germline_workflow.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#germline_workflow.cwl/bgzip"
                },
                {
                    "run": "#single_sample_docm_filter.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/gatk_haplotypecaller/docm_out",
                            "id": "#germline_workflow.cwl/docm_filter/docm_out"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/docm_filter/docm_filter_out"
                    ],
                    "id": "#germline_workflow.cwl/docm_filter"
                },
                {
                    "run": "#germline_gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/cram",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl/docm_vcf",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/docm_vcf"
                        },
                        {
                            "source": "#germline_workflow.cwl/interval_list",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#germline_workflow.cwl/reference",
                            "id": "#germline_workflow.cwl/gatk_haplotypecaller/reference"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/gatk_haplotypecaller/docm_out"
                    ],
                    "id": "#germline_workflow.cwl/gatk_haplotypecaller"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl/bgzip/bgzipped_file",
                            "id": "#germline_workflow.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl/index/indexed_vcf"
                    ],
                    "id": "#germline_workflow.cwl/index"
                }
            ],
            "id": "#germline_workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/single_sample_docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#single_sample_docm_filter.cwl/docm_out"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#single_sample_docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#single_sample_docm_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "--splitMultiallelics",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_2/min_var_freq"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#workflow.cwl_2/sample_name"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram",
                            "id": "#workflow.cwl_2/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl_2/cram_to_bam"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_filter/filtered_vcf",
                            "id": "#workflow.cwl_2/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_2/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/cram_to_bam/bam",
                            "id": "#workflow.cwl_2/fp_filter/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/min_var_freq",
                            "id": "#workflow.cwl_2/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#workflow.cwl_2/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/fp_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/sample_name",
                            "id": "#workflow.cwl_2/fp_filter/sample_name"
                        },
                        {
                            "source": "#workflow.cwl_2/normalize_variants/normalized_vcf",
                            "id": "#workflow.cwl_2/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/fp_bgzip/bgzipped_file",
                            "id": "#workflow.cwl_2/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/fp_index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_2/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#workflow.cwl_2/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#workflow.cwl_2/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#workflow.cwl_2/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/hard_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/fp_index/indexed_vcf",
                            "id": "#workflow.cwl_2/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/hard_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_2/hard_filter"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/normalize_variants/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/vcf",
                            "id": "#workflow.cwl_2/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/normalize_variants/normalized_vcf"
                    ],
                    "id": "#workflow.cwl_2/normalize_variants"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/bin/cat",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_snv.tsv",
                "$(runtime.outdir)/$(inputs.sample)_bam_readcount_indel.tsv"
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_readcount.cwl/bam_readcount_tsv",
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount.tsv"
                    }
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect gc bias metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectGcBiasMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetrics.txt"
                },
                "CHART=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsChart.pdf"
                },
                "S=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsSummary.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_gc_bias_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetrics.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsChart.pdf"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsSummary.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_summary"
                }
            ],
            "id": "#collect_gc_bias_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "WGS QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow_wgs.cwl/cram"
                },
                {
                    "type": "File",
                    "id": "#workflow_wgs.cwl/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow_wgs.cwl/omni_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#workflow_wgs.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#workflow_wgs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#workflow_wgs.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/samtools_flagstat/flagstats",
                    "id": "#workflow_wgs.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#workflow_wgs.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#workflow_wgs.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#workflow_wgs.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#workflow_wgs.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_wgs_metrics/wgs_metrics",
                    "id": "#workflow_wgs.cwl/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_gc_bias_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary"
                    ],
                    "id": "#workflow_wgs.cwl/collect_gc_bias_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#workflow_wgs.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/intervals",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/intervals"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#workflow_wgs.cwl/collect_wgs_metrics"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow_wgs.cwl/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#workflow_wgs.cwl/samtools_flagstat"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram_to_bam/bam",
                            "id": "#workflow_wgs.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#workflow_wgs.cwl/omni_vcf",
                            "id": "#workflow_wgs.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#workflow_wgs.cwl/verify_bam_id"
                }
            ],
            "id": "#workflow_wgs.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/Final.bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "Final.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "stdout": "final.cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "final.cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mark duplicates and sort",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 3,
                    "valueFrom": "$(runtime.outdir)/MarkedSorted.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "MarkedSorted.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "merge BAMs",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "arguments": [
                "AlignedMerged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignedMerged.bam"
                    },
                    "id": "#merge.cwl/merged_bam"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "12G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 13000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR and VCF",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#workflow.cwl_3/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#workflow.cwl_3/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#workflow.cwl_3/readgroups"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_3/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_3/final_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/mark_duplicates_and_sort/metrics_file",
                    "id": "#workflow.cwl_3/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#workflow.cwl_3/align/bam",
                        "#workflow.cwl_3/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/bams",
                            "id": "#workflow.cwl_3/align/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/readgroups",
                            "id": "#workflow.cwl_3/align/readgroup"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/align/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/align/tagged_bam"
                    ],
                    "id": "#workflow.cwl_3/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_3/apply_bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/bqsr/bqsr_table",
                            "id": "#workflow.cwl_3/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#workflow.cwl_3/apply_bqsr"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/apply_bqsr/bqsr_bam",
                            "id": "#workflow.cwl_3/bam_to_cram/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/bam_to_cram/cram"
                    ],
                    "id": "#workflow.cwl_3/bam_to_cram"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_3/bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/bqsr_intervals",
                            "id": "#workflow.cwl_3/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#workflow.cwl_3/dbsnp",
                                "#workflow.cwl_3/mills",
                                "#workflow.cwl_3/known_indels"
                            ],
                            "id": "#workflow.cwl_3/bqsr/known_sites"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/bqsr/bqsr_table"
                    ],
                    "id": "#workflow.cwl_3/bqsr"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/bam_to_cram/cram",
                            "id": "#workflow.cwl_3/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/index_cram/indexed_cram"
                    ],
                    "id": "#workflow.cwl_3/index_cram"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/name_sort/name_sorted_bam",
                            "id": "#workflow.cwl_3/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/mark_duplicates_and_sort/sorted_bam",
                        "#workflow.cwl_3/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#workflow.cwl_3/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/align/tagged_bam",
                            "id": "#workflow.cwl_3/merge/bams"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/merge/merged_bam"
                    ],
                    "id": "#workflow.cwl_3/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/merge/merged_bam",
                            "id": "#workflow.cwl_3/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/name_sort/name_sorted_bam"
                    ],
                    "id": "#workflow.cwl_3/name_sort"
                }
            ],
            "id": "#workflow.cwl_3"
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#germline_workflow.cwl_2/cram"
                },
                {
                    "type": "File",
                    "id": "#germline_workflow.cwl_2/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#germline_workflow.cwl_2/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#germline_workflow.cwl_2/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#germline_workflow.cwl_2/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#germline_workflow.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#germline_workflow.cwl_2/p_value"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl_2/reference"
                },
                {
                    "type": "string",
                    "id": "#germline_workflow.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#germline_workflow.cwl_2/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl_2/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_workflow.cwl_2/filter/unfiltered_vcf",
                    "id": "#germline_workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/varscan/variants",
                            "id": "#germline_workflow.cwl_2/bgzip_and_index/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/bgzip_and_index/indexed_vcf"
                    ],
                    "id": "#germline_workflow.cwl_2/bgzip_and_index"
                },
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/cram",
                            "id": "#germline_workflow.cwl_2/filter/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_var_freq",
                            "id": "#germline_workflow.cwl_2/filter/min_var_freq"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/reference",
                            "id": "#germline_workflow.cwl_2/filter/reference"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/sample_name",
                            "id": "#germline_workflow.cwl_2/filter/sample_name"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#germline_workflow.cwl_2/filter/variant_caller"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/bgzip_and_index/indexed_vcf",
                            "id": "#germline_workflow.cwl_2/filter/vcf"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/filter/unfiltered_vcf",
                        "#germline_workflow.cwl_2/filter/filtered_vcf"
                    ],
                    "id": "#germline_workflow.cwl_2/filter"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/interval_list",
                            "id": "#germline_workflow.cwl_2/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/intervals_to_bed/interval_bed"
                    ],
                    "id": "#germline_workflow.cwl_2/intervals_to_bed"
                },
                {
                    "run": "#varscan_germline.cwl",
                    "in": [
                        {
                            "source": "#germline_workflow.cwl_2/cram",
                            "id": "#germline_workflow.cwl_2/varscan/cram"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_coverage",
                            "id": "#germline_workflow.cwl_2/varscan/min_coverage"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_reads",
                            "id": "#germline_workflow.cwl_2/varscan/min_reads"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/min_var_freq",
                            "id": "#germline_workflow.cwl_2/varscan/min_var_freq"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/p_value",
                            "id": "#germline_workflow.cwl_2/varscan/p_value"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/reference",
                            "id": "#germline_workflow.cwl_2/varscan/reference"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/intervals_to_bed/interval_bed",
                            "id": "#germline_workflow.cwl_2/varscan/roi_bed"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/sample_name",
                            "id": "#germline_workflow.cwl_2/varscan/sample_name"
                        },
                        {
                            "source": "#germline_workflow.cwl_2/strand_filter",
                            "id": "#germline_workflow.cwl_2/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#germline_workflow.cwl_2/varscan/variants"
                    ],
                    "id": "#germline_workflow.cwl_2/varscan"
                }
            ],
            "id": "#germline_workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/intervals_to_bed.pl"
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 germline",
            "baseCommand": "/usr/bin/varscan_germline_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "arguments": [
                {
                    "position": 9,
                    "valueFrom": "$(runtime.outdir)/output.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_germline.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_germline.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_germline.cwl/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_germline.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_germline.cwl/p_value"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#varscan_germline.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#varscan_germline.cwl/roi_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_germline.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_germline.cwl/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf"
                    },
                    "id": "#varscan_germline.cwl/variants"
                }
            ],
            "id": "#varscan_germline.cwl"
        },
        {
            "class": "Workflow",
            "label": "wgs alignment with qc",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#wgs_alignment.cwl/bams"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/dbsnp"
                },
                {
                    "type": "File",
                    "id": "#wgs_alignment.cwl/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/omni_vcf"
                },
                {
                    "type": "string",
                    "id": "#wgs_alignment.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#wgs_alignment.cwl/readgroups"
                },
                {
                    "type": "string",
                    "id": "#wgs_alignment.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/alignment_summary_metrics",
                    "id": "#wgs_alignment.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/alignment/final_cram",
                    "id": "#wgs_alignment.cwl/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/flagstats",
                    "id": "#wgs_alignment.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics_chart",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics_summary",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/insert_size_histogram",
                    "id": "#wgs_alignment.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/insert_size_metrics",
                    "id": "#wgs_alignment.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/alignment/mark_duplicates_metrics_file",
                    "id": "#wgs_alignment.cwl/mark_duplicates_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/verify_bam_id_depth",
                    "id": "#wgs_alignment.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/verify_bam_id_metrics",
                    "id": "#wgs_alignment.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/wgs_metrics",
                    "id": "#wgs_alignment.cwl/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#wgs_alignment.cwl/bams",
                            "id": "#wgs_alignment.cwl/alignment/bams"
                        },
                        {
                            "source": "#wgs_alignment.cwl/dbsnp",
                            "id": "#wgs_alignment.cwl/alignment/dbsnp"
                        },
                        {
                            "source": "#wgs_alignment.cwl/known_indels",
                            "id": "#wgs_alignment.cwl/alignment/known_indels"
                        },
                        {
                            "source": "#wgs_alignment.cwl/mills",
                            "id": "#wgs_alignment.cwl/alignment/mills"
                        },
                        {
                            "source": "#wgs_alignment.cwl/readgroups",
                            "id": "#wgs_alignment.cwl/alignment/readgroups"
                        },
                        {
                            "source": "#wgs_alignment.cwl/reference",
                            "id": "#wgs_alignment.cwl/alignment/reference"
                        }
                    ],
                    "out": [
                        "#wgs_alignment.cwl/alignment/final_cram",
                        "#wgs_alignment.cwl/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#wgs_alignment.cwl/alignment"
                },
                {
                    "run": "#workflow_wgs.cwl",
                    "in": [
                        {
                            "source": "#wgs_alignment.cwl/alignment/final_cram",
                            "id": "#wgs_alignment.cwl/qc/cram"
                        },
                        {
                            "source": "#wgs_alignment.cwl/intervals",
                            "id": "#wgs_alignment.cwl/qc/intervals"
                        },
                        {
                            "source": "#wgs_alignment.cwl/omni_vcf",
                            "id": "#wgs_alignment.cwl/qc/omni_vcf"
                        },
                        {
                            "source": "#wgs_alignment.cwl/picard_metric_accumulation_level",
                            "id": "#wgs_alignment.cwl/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#wgs_alignment.cwl/reference",
                            "id": "#wgs_alignment.cwl/qc/reference"
                        }
                    ],
                    "out": [
                        "#wgs_alignment.cwl/qc/insert_size_metrics",
                        "#wgs_alignment.cwl/qc/insert_size_histogram",
                        "#wgs_alignment.cwl/qc/alignment_summary_metrics",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics_chart",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics_summary",
                        "#wgs_alignment.cwl/qc/wgs_metrics",
                        "#wgs_alignment.cwl/qc/flagstats",
                        "#wgs_alignment.cwl/qc/verify_bam_id_metrics",
                        "#wgs_alignment.cwl/qc/verify_bam_id_depth"
                    ],
                    "id": "#wgs_alignment.cwl/qc"
                }
            ],
            "id": "#wgs_alignment.cwl"
        },
        {
            "class": "Workflow",
            "label": "wgs alignment and germline variant detection",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp"
                },
                {
                    "type": "File",
                    "id": "#main/docm_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": "File",
                    "id": "#main/qc_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroups"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": "File",
                    "id": "#main/variant_detection_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/vep_cache_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/annotated_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/cram",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/docm_gatk_vcf",
                    "id": "#main/docm_gatk_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics",
                    "id": "#main/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_chart",
                    "id": "#main/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_summary",
                    "id": "#main/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/mark_duplicates_metrics",
                    "id": "#main/mark_duplicates_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/tumor_bam_readcount_tsv",
                    "id": "#main/tumor_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/varscan_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/vep_summary",
                    "id": "#main/vep_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#wgs_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/alignment_and_qc/bams"
                        },
                        {
                            "source": "#main/dbsnp",
                            "id": "#main/alignment_and_qc/dbsnp"
                        },
                        {
                            "source": "#main/qc_intervals",
                            "id": "#main/alignment_and_qc/intervals"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/alignment_and_qc/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/alignment_and_qc/mills"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/alignment_and_qc/omni_vcf"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/alignment_and_qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/readgroups",
                            "id": "#main/alignment_and_qc/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment_and_qc/reference"
                        }
                    ],
                    "out": [
                        "#main/alignment_and_qc/cram",
                        "#main/alignment_and_qc/mark_duplicates_metrics",
                        "#main/alignment_and_qc/insert_size_metrics",
                        "#main/alignment_and_qc/insert_size_histogram",
                        "#main/alignment_and_qc/alignment_summary_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics_chart",
                        "#main/alignment_and_qc/gc_bias_metrics_summary",
                        "#main/alignment_and_qc/wgs_metrics",
                        "#main/alignment_and_qc/flagstats",
                        "#main/alignment_and_qc/verify_bam_id_metrics",
                        "#main/alignment_and_qc/verify_bam_id_depth"
                    ],
                    "id": "#main/alignment_and_qc"
                },
                {
                    "run": "#tumor_only_detect_variants.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_and_qc/cram",
                            "id": "#main/detect_variants/cram"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/detect_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/detect_variants/docm_vcf"
                        },
                        {
                            "source": "#main/variant_detection_intervals",
                            "id": "#main/detect_variants/interval_list"
                        },
                        {
                            "source": "#main/min_base_quality",
                            "id": "#main/detect_variants/min_base_quality"
                        },
                        {
                            "source": "#main/min_mapping_quality",
                            "id": "#main/detect_variants/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/detect_variants/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/detect_variants/sample_name"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/detect_variants/synonyms_file"
                        },
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/detect_variants/vep_cache_dir"
                        }
                    ],
                    "out": [
                        "#main/detect_variants/varscan_vcf",
                        "#main/detect_variants/docm_gatk_vcf",
                        "#main/detect_variants/annotated_vcf",
                        "#main/detect_variants/final_vcf",
                        "#main/detect_variants/final_tsv",
                        "#main/detect_variants/vep_summary",
                        "#main/detect_variants/tumor_bam_readcount_tsv"
                    ],
                    "id": "#main/detect_variants"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
